/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
export declare class IgDataChartComponent extends IgControlBase<IgDataChart> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    set dataSource(value: any);
    private _dataSource;
    ngOnInit(): void;
    option(): void;
    /**
     * Returns the element holding the chart.
     */
    widget(): void;
    /**
     * Returns the ID of parent element holding the chart.
     */
    id(): string;
    /**
     * Exports the chart to a PNG image.
     *
     * @param width     The width of the image.
     * @param height     The height of the image.
     */
    exportImage(width?: object, height?: object): object;
    /**
     * Destroys the widget.
     */
    destroy(): void;
    /**
     * Notify the chart that styles it draws colors from may have been updated.
     */
    styleUpdated(): object;
    /**
     * Resets the zoom level of the chart to default.
     */
    resetZoom(): object;
    /**
     * Adds a new item to the data source and notifies the chart.
     *
     * @param item     The item that we want to add to the data source.
     * @param targetName     The name of the series or axis bound to the data source.
     * This is required only when the data is bound to series or axis.
     * If the data is bound to dataSource of igDataChart, the second parameter should not be set.
     */
    addItem(item: object, targetName: string): void;
    /**
     * Inserts a new item to the data source and notifies the chart.
     *
     * @param item     the new item that we want to insert in the data source.
     * @param index     The index in the data source where the new item will be inserted.
     * @param targetName     The name of the series or axis bound to the data source.
     */
    insertItem(item: object, index: number, targetName: string): void;
    /**
     * Deletes an item from the data source and notifies the chart.
     *
     * @param index     The index in the data source from where the item will be been removed.
     * @param targetName     The name of the series or axis bound to the data source.
     * This is required only when the data is bound to series or axis.
     * If the data is bound to dataSource of igDataChart, the second parameter should not be set.
     */
    removeItem(index: number, targetName: string): void;
    /**
     * Updates an item in the data source and notifies the chart.
     *
     * @param index     The index of the item in the data source that we want to change.
     * @param item     The new item object that will be set in the data source.
     * @param targetName     The name of the series or axis bound to the data source.
     */
    setItem(index: number, item: object, targetName: string): void;
    /**
     * Notifies the chart that an item has been set in an associated data source.
     *
     * @param dataSource     The data source in which the change happened.
     * @param index     The index in the items source that has been changed.
     * @param newItem     the new item that has been set in the collection.
     * @param oldItem     the old item that has been overwritten in the collection.
     */
    notifySetItem(dataSource: object, index: number, newItem: object, oldItem: object): object;
    /**
     * Notifies the chart that the items have been cleared from an associated data source.
     * 				It's not necessary to notify more than one target of a change if they share the same items source.
     *
     * @param dataSource     The data source in which the change happened.
     */
    notifyClearItems(dataSource: object): object;
    /**
     * Notifies the target axis or series that an item has been inserted at the specified index in its data source.
     * 				It's not necessary to notify more than one target of a change if they share the same items source.
     *
     * @param dataSource     The data source in which the change happened.
     * @param index     The index in the items source where the new item has been inserted.
     * @param newItem     the new item that has been set in the collection.
     */
    notifyInsertItem(dataSource: object, index: number, newItem: object): object;
    /**
     * Notifies the target axis or series that an item has been removed from the specified index in its data source.
     * 				It's not necessary to notify more than one target of a change if they share the same items source.
     *
     * @param dataSource     The data source in which the change happened.
     * @param index     The index in the items source from where the old item has been removed.
     * @param oldItem     the old item that has been removed from the collection.
     */
    notifyRemoveItem(dataSource: object, index: number, oldItem: object): object;
    /**
     * Notifies the target axis or series that it should scroll the requested data item into view.
     *
     * @param targetName     The name of the axis or series notify.
     * @param item     The data item to bring into view, if possible.
     */
    scrollIntoView(targetName: string, item: object): object;
    /**
     * Notifies the target axis that it should scale the requested value into chart space from axis space.
     * 				For example you can use this method if you want to find where value 50 of the x axis stands scaled to chart's width.
     *
     * @param targetName     The name of the axis to notify.
     * @param unscaledValue     The value in axis space to translate into chart space.
     */
    scaleValue(targetName: string, unscaledValue: number): number;
    /**
     * Notifies the target axis that it should unscale the requested value into axis space from chart space.
     * 				For example you can use this method if you want to find what is the value of x axis unscaled from 0 width of the chart.
     *
     * @param targetName     The name of the axis to notify.
     * @param scaledValue     The value in chart space to translate into axis space.
     */
    unscaleValue(targetName: string, scaledValue: number): number;
    /**
     * For the target axis, if using enhanced interval management and precise interval fitting,
     * this will reset the cached maximum label width, and recalculate using the current labels.
     *
     * @param targetName     The name of the axis to notify.
     */
    resetCachedEnhancedInterval(targetName: string): object;
    /**
     * Notifies the target series that something that affects its visual properties has changed and the visual output needs a repaint.
     *
     * @param targetName     The name of the series to notify.
     */
    notifyVisualPropertiesChanged(targetName: string): object;
    /**
     * Forces any pending deferred work to render on the chart before continuing
     */
    flush(): void;
    /**
     * Exports visual data from the chart to aid in unit testing
     */
    exportVisualData(): void;
    /**
     * Gets the actual minimum value of the target numeric or date time axis
     *
     * @param targetName    The name of the axis from which to get the minimum value.
     */
    getActualMinimumValue(targetName: string): void;
    /**
     * Gets the actual maximum value of the target numeric or date time axis
     *
     * @param targetName    The name of the axis from which to get the maximum value.
     */
    getActualMaximumValue(targetName: string): void;
    /**
     * Gets the actual interval of the target numeric or date time axis
     *
     * @param targetName    The name of the axis from which to get the interval.
     */
    getActualInterval(targetName: string): void;
    /**
     * Creates a print preview page with the chart, hiding all other elements on the page.
     */
    print(): void;
    /**
     * Indicates that a series should render, even though no option has been modified that would normally cause it to refresh.
     *
     * @param targetName     The name of the series to render.
     * @param animate     Whether the change should be animated, if possible.
     */
    renderSeries(targetName: string, animate: boolean): void;
    /**
     * Gets the item item index associated with the specified world position.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     */
    getItemIndex(targetName: string, worldPoint: object): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     */
    getItem(targetName: string, worldPoint: object): object;
    /**
     * For a category plotted series, gets the current width of the items within the categories.
     * This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
     *
     * @param targetName    The name of the series to target.
     */
    getItemSpan(targetName: string): number;
    /**
     * If possible, will return the best available main value of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesValue(targetName: string, worldPoint: object, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value
     * match for the world position provided.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     */
    getSeriesValueBoundingBox(targetName: string, worldPoint: object): object;
    /**
     * If possible, will return the best available value fine grained bounding boxes within the series that have the best value
     * match for the world position provided.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     */
    getSeriesValueFineGrainedBoundingBoxes(targetName: string, worldPoint: object): object;
    /**
     * If possible, will return the best available main value position of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesValuePosition(targetName: string, worldPoint: object, useInterpolation: boolean, skipUnknowns: boolean): object;
    /**
     * If possible, will return the best available main value position of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]}
     * that represents a position within the pixel space of the series.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesValuePositionFromSeriesPixel(targetName: string, seriesPoint: object, useInterpolation: boolean, skipUnknowns: boolean): object;
    /**
     * If possible, will return the best available main value of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]} )
     * that represents a position in the pixel space of the series.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesValueFromSeriesPixel(targetName: string, seriesPoint: object, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value
     * match for the given series pixel coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]} )
     * that represents a position in the pixel space of the series.
     */
    getSeriesValueBoundingBoxFromSeriesPixel(targetName: string, seriesPoint: object): object;
    /**
     * If possible, will return the best available value fine grained bounding boxes within the series that have the best value
     * match for series pixel position provided.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The series pixel position (in the form {x: [number], y: [number]} )
     * that represents a position in the pixel space of the series.
     */
    getSeriesValueFineGrainedBoundingBoxesFromSeriesPixel(targetName: string, worldPoint: object): object;
    /**
     * If possible, will return the best available high value of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesHighValue(targetName: string, worldPoint: object, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * If possible, will return the best available high value position of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesHighValuePosition(targetName: string, worldPoint: object, useInterpolation: boolean, skipUnknowns: boolean): object;
    /**
     * If possible, will return the best available high value position of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]}
     * that represents a position within the pixel space of the series.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesHighValuePositionFromSeriesPixel(targetName: string, seriesPoint: object, useInterpolation: boolean, skipUnknowns: boolean): object;
    /**
     * If possible, will return the best available high value of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]} )
     * that represents a position in the pixel space of the series.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesHighValueFromSeriesPixel(targetName: string, seriesPoint: object, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * If possible, will return the best available low value of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesLowValue(targetName: string, worldPoint: object, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * If possible, will return the best available low value position of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesLowValuePosition(targetName: string, worldPoint: object, useInterpolation: boolean, skipUnknowns: boolean): object;
    /**
     * If possible, will return the best available low value position of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]}
     * that represents a position within the pixel space of the series.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesLowValuePositionFromSeriesPixel(targetName: string, seriesPoint: object, useInterpolation: boolean, skipUnknowns: boolean): object;
    /**
     * If possible, will return the best available low value of the series for a given world coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]} )
     * that represents a position in the pixel space of the series.
     * @param useInterpolation    If true, interpolation should be used to get in-between values,
     * rather than only the actual values in the data set.
     * @param skipUnknowns    If true, unknown values should be skipped.
     */
    getSeriesLowValueFromSeriesPixel(targetName: string, seriesPoint: object, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * Gets the item item index associated with the specified series pixel coordinate.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The world position (in the form {x: [number from 0 to 1], y: [number from 0 to 1]} )
     * that represents a position in the space of the axes.
     */
    getItemIndexFromSeriesPixel(targetName: string, seriesPoint: object): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The series pixel position (in the form {x: [number], y: [number]} )
     * that represents a position in the pixel space of the series.
     */
    getItemFromSeriesPixel(targetName: string, seriesPoint: object): object;
    /**
     * Gets the category offset for a series, if applicable.
     *
     * @param targetName    The name of the series to target.
     */
    getSeriesOffsetValue(targetName: string): number;
    /**
     * Gets the category width for a series, if applicable.
     *
     * @param targetName    The name of the series to target.
     */
    getSeriesCategoryWidth(targetName: string): number;
    /**
     * Replays the transition in animation for a series, if applicable.
     *
     * @param targetName    The name of the series to target.
     */
    replayTransitionIn(targetName: string): object;
    /**
     * Simulates a hover interaction over a given point in the viewport of a series.
     *
     * @param targetName    The name of the series to target.
     * @param seriesPoint    The point at which to hover. Should have an x property with type number and a y property with type number.
     */
    simulateHover(targetName: string, seriesPoint: object): object;
    /**
     * Moves the cursor point of the target annotation layer to the desired world coordinates.
     *
     * @param targetName    The name of the series to target.
     * @param worldPoint    The point to which to move the cursor.
     * Should have an x property with type number and a y property with type number.
     */
    moveCursorPoint(targetName: string, worldPoint: object): object;
    /**
     * Manually starts a tiled zoom if one isn't already running.
     */
    startTiledZoomingIfNecessary(): void;
    /**
     * Manually ends a tiled zoom if one is running.
     */
    endTiledZoomingIfRunning(): void;
    /**
     * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
     */
    clearTileZoomCache(): void;
}
