/// <reference types="ignite-ui" />
import { IgEditorBase } from './igeditorbase';
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { NgModel } from '@angular/forms';
export declare class IgDateEditorComponent extends IgEditorBase<IgDateEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Changes the the regional settings of widget element to the language specified in [options.regional](ui.igdateeditor#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.igdateeditor#options:regional) option setter
     */
    changeRegional(): void;
    /**
     * Gets/Sets editor value.
     *
     * Note! This option doesn't use the dateInputFormat to extract the date
     *
     * @param newValue New editor value. Date object can be set as value. String value can be passed and the editor will use
     * the javascript Date object constructor to create date object and will use it for the comparison.
     * MVC date format can be used too. For example Date(/"ticks"/).
     */
    value(newValue?: Date): Date;
    /**
     * Gets selected date as a date object. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() method will not return date object and getSelectedDate() can be used to replace that functionality.
     */
    getSelectedDate(): Date;
    /**
     * Sets selected date. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() cannot accept a date object as a new value and getSelectedDate() can be used to replace that functionality.
     *
     * @param date date
     */
    selectDate(date: Date): void;
    /**
     * Increases the date or time period, depending on the current cursor position.
     *
     * @param delta The increase delta.
     */
    spinUp(delta?: number): void;
    /**
     * Decreases the date or time period, depending on the current cursor position.
     *
     * @param delta The decrease delta.
     */
    spinDown(delta?: number): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    dropDownButton(): void;
    dropDownContainer(): void;
    dropDownVisible(): void;
    findListItemIndex(): void;
    getSelectedListItem(): void;
    selectedListIndex(): void;
    showDropDown(): void;
    hideDropDown(): void;
}
