/// <reference types="ignite-ui" />
import { IgEditorBase } from './igeditorbase';
import { IterableDiffers, ElementRef, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { NgModel } from '@angular/forms';
export declare class IgMaskEditorComponent extends IgEditorBase<IgMaskEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Gets/Sets mask editor value.
     *
     * @param newValue New mask editor value.
     */
    value(newValue?: string): string;
    dropDownContainer(): void;
    showDropDown(): void;
    hideDropDown(): void;
    dropDownButton(): void;
    spinUpButton(): void;
    spinDownButton(): void;
    dropDownVisible(): void;
    findListItemIndex(): void;
    selectedListIndex(): void;
    getSelectedListItem(): void;
    spinUp(): void;
    spinDown(): void;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    /**
     * Changes the all locales into the widget element to the language specified in [options.language](ui.igtexteditor#options:language)
     * Note that this method is for rare scenarios, see [language](ui.igtexteditor#options:language) or
     * [locale](ui.igtexteditor#options:locale) option setter
     */
    changeLocale(): void;
    /**
     * Gets the visible text in the editor.
     */
    displayValue(): string;
    /**
     * Returns a reference to the clear button UI element of the editor.
     */
    clearButton(): string;
    /**
     * Gets the selected text from the editor in edit mode. This can be done inside key event handlers, like keydown or keyup.
     * This method can be used only when the editor is focused.
     * If you invoke this method in display mode, when the editor input is blurred, the returned value will be an empty string.
     */
    getSelectedText(): string;
    /**
     * Gets the start index of the selected text in the editor.
     */
    getSelectionStart(): number;
    /**
     * Gets the end index of the selected text in the editor.
     */
    getSelectionEnd(): number;
    /**
     * Inserts the text at the location of the caret or over the current selection.
     * If the editor is focused the method will insert the text over the current selection.
     * If the editor is not focused the method will set the text as value of the editor.
     * Note: The method raises [textChanged](ui.igtexteditor#events:textChanged) event.
     *
     * @param value The string to be inserted.
     */
    insert(value: string): void;
    /**
     * Selects the text between start and end indices in the editor.
     * If the parameters are equal, then the method sets location of caret. The method has effect only when the editor has focus.
     *
     * @param start Start of the selection.
     * @param end End of the selection.
     */
    select(start: number, end: number): void;
}
