/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgEditorBase } from './igeditorbase';
import { NgModel } from '@angular/forms';
export declare class IgNumericEditorComponent extends IgEditorBase<IgNumericEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Gets/Sets editor value.
     *
     * @param newValue New editor value.
     */
    value(newValue?: number): number;
    /**
     * Finds index of list item by text that matches with the search parameters.
     *
     * @param value The text to search for.
     */
    findListItemIndex(value: number): number;
    getSelectedText(): void;
    getSelectionStart(): void;
    getSelectionEnd(): void;
    /**
     * Increments value in editor according to the parameter or selects the previous item from the drop-down list if
     * [isLimitedToListValues](ui.%%WidgetNameLowered%%#options:isLimitedToListValues) is enabled.
     *
     * @param delta Increments value.
     */
    spinUp(delta?: number): void;
    /**
     * Decrements value in editor according to the parameter selects the next item from the drop-down list if
     * [isLimitedToListValues](ui.%%WidgetNameLowered%%#options:isLimitedToListValues) is enabled.
     *
     * @param delta Decrement value.
     */
    spinDown(delta?: number): void;
    /**
     * This method is deprecated in favor of [spinUp](ui.%%WidgetNameLowered%%#options:spinUp).
     */
    selectListIndexUp(): void;
    /**
     * This method is deprecated in favor of [spinDown](ui.%%WidgetNameLowered%%#options:spinDown).
     */
    selectListIndexDown(): void;
    /**
     * Gets current regional.
     */
    getRegionalOption(): string;
    /**
     * Changes the the regional settings of widget element to the language specified in
     * [options.regional](ui.ignumericeditor#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.ignumericeditor#options:regional) option setter
     */
    changeRegional(): void;
    /**
     * Changes the all locales into the widget element to the language specified in [options.language](ui.igtexteditor#options:language)
     * Note that this method is for rare scenarios, see [language](ui.igtexteditor#options:language) or
     * [locale](ui.igtexteditor#options:locale) option setter
     */
    changeLocale(): void;
    /**
     * Gets the visible text in the editor.
     */
    displayValue(): string;
    /**
     * Gets reference to jquery object which is used as container of drop-down list.
     */
    dropDownContainer(): string;
    /**
     * Shows the drop down list.
     */
    showDropDown(): void;
    /**
     * Hides the drop down list.
     */
    hideDropDown(): void;
    /**
     * Returns a reference to the drop-down button UI element of the editor.
     */
    dropDownButton(): string;
    /**
     * Returns if the drop-down list is visible.
     */
    dropDownVisible(): boolean;
    /**
     * Returns a reference to the clear button UI element of the editor.
     */
    clearButton(): string;
    /**
     * Gets the index of the selected list item. Sets selected item by index.
     *
     * @param index The index of the item that needs to be selected.
     */
    selectedListIndex(index?: number): number;
    /**
     * Gets the selected list item.
     */
    getSelectedListItem(): string;
    /**
     * Inserts the text at the location of the caret or over the current selection.
     * If the editor is focused the method will insert the text over the current selection.
     * If the editor is not focused the method will set the text as value of the editor.
     * Note: The method raises [textChanged](ui.igtexteditor#events:textChanged) event.
     *
     * @param value The string to be inserted.
     */
    insert(value: string): void;
    /**
     * Selects the text between start and end indices in the editor.
     * If the parameters are equal, then the method sets location of caret. The method has effect only when the editor has focus.
     *
     * @param start Start of the selection.
     * @param end End of the selection.
     */
    select(start: number, end: number): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
}
