/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgEditorBase } from './igeditorbase';
import { NgModel } from '@angular/forms';
export declare class IgPercentEditorComponent extends IgEditorBase<IgPercentEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Paste text at location of the caret or over the current selection.
     * Best used during editing, as the method will instead set the text as value
     * (modified by the [displayFactor](ui.igpercenteditor#options:displayFactor)) if the editor is not focused.
     * Note: the method raises the [textChanged](ui.igpercenteditor#events:textChanged) event.
     *
     * @param value The string to be inserted.
     */
    insert(value: string): void;
    /**
     * Gets/Sets a string that is used as the percent symbol shown with the number in the input.
     * The value provided as a param is propagated to the [percentSymbol](ui.igpercenteditor#options:percentSymbol)
     * option and thus has the same priority as the option.
     *
     * @param symbol New percent symbol.
     */
    percentSymbol(symbol?: object): string;
    /**
     * Gets/Sets editor value.
     *
     * @param newValue New editor value.
     */
    value(newValue?: number): number;
    /**
     * Finds index of list item by text that matches with the search parameters.
     *
     * @param value The text to search for.
     */
    findListItemIndex(value: number): number;
    getSelectedText(): void;
    getSelectionStart(): void;
    getSelectionEnd(): void;
    /**
     * Increments value in editor according to the parameter or selects the previous item from the drop-down list if
     * [isLimitedToListValues](ui.%%WidgetNameLowered%%#options:isLimitedToListValues) is enabled.
     *
     * @param delta Increments value.
     */
    spinUp(delta?: number): void;
    /**
     * Decrements value in editor according to the parameter selects the next item from the drop-down list if
     * [isLimitedToListValues](ui.%%WidgetNameLowered%%#options:isLimitedToListValues) is enabled.
     *
     * @param delta Decrement value.
     */
    spinDown(delta?: number): void;
    /**
     * This method is deprecated in favor of [spinUp](ui.%%WidgetNameLowered%%#options:spinUp).
     */
    selectListIndexUp(): void;
    /**
     * This method is deprecated in favor of [spinDown](ui.%%WidgetNameLowered%%#options:spinDown).
     */
    selectListIndexDown(): void;
    /**
     * Gets current regional.
     */
    getRegionalOption(): string;
    /**
     * Changes the the regional settings of widget element to the language specified in
     * [options.regional](ui.ignumericeditor#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.ignumericeditor#options:regional) option setter
     */
    changeRegional(): void;
}
