/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
export declare class IgGridGroupByFeature extends Feature<IgGridGroupBy> {
    constructor(el: ElementRef);
    /**
     * Open groupby modal dialog
     */
    openGroupByDialog(): void;
    /**
     * Close groupby modal dialog
     */
    closeGroupByDialog(): void;
    /**
     * Render groupby modal dialog and its content
     */
    renderGroupByModalDialog(): void;
    /**
     * Open layouts dropdown
     */
    openDropDown(): void;
    /**
     * Close layouts dropdown
     */
    closeDropDown(): void;
    /**
     * Check whether column with specified key and layout is grouped
     *
     * @param key    key of the column
     * @param layout    layout name
     */
    checkColumnIsGrouped(key: string, layout: string): void;
    /**
     * Get grouped data by value for the specific column.
     * NOTE: Before calling this function the data(that is passed as an argument) should be sorted by colKey.
     *
     * @param data    data (sorted by colKey) that is used to get the records from.
     * @param colKey    key of the column for which grouping will be applied.
     * @param idval    value of the column by which grouping will be applied.
     */
    getGroupedData(data: any[], colKey: string, idval?: string): any[];
    /**
     * Adds a column to the group by columns list, executes the group by operation and updates the view.
     */
    groupByColumns(): object;
    /**
     * Groups by a column
     *
     * @param key    Column Key - group by the column with the specified key
     * @param layout    layout is an optional parameter.
     * If set it means the grouped column is not in the root level but is a child layout column
     * @param sortingDirection    if not set it is taken from option defaultSortingDirection
     */
    groupByColumn(key: string, layout?: string, sortingDirection?: object): void;
    /**
     * Removes the specified column from the group by columns list, executes the group by operation and updates the view.
     *
     * @param key    Column Key - ungroup by the column with the specified key
     * @param layout    Layout is an optional parameter.
     * If set it means the grouped column is not in the root level but is a child layout column.
     */
    ungroupByColumn(key: string, layout?: string): void;
    /**
     * Expand group row with specified id
     *
     * @param rowId    data-id attribute of the group row in the DOM
     */
    expand(rowId: string): void;
    /**
     * Expand group row with specified id
     *
     * @param rowId    data-id attribute of the group row in the DOM
     */
    collapse(rowId: string): void;
    /**
     * Clears the group by columns list and updates the view.
     */
    ungroupAll(): void;
    /**
     * Destroys the group by feature object.
     */
    destroy(): void;
}
