/// <reference types="ignite-ui" />
import { IterableDiffers, KeyValueDiffers, ChangeDetectorRef, ElementRef, Renderer2 } from '@angular/core';
import { IgGridBase } from '../iggrid/iggridbase';
export declare class IgHierarchicalGridComponent extends IgGridBase<IgHierarchicalGrid> {
    childrenDataProperty: string;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    deleteRow(id: any): void;
    updateRow(rec: any, currValue: any, key: any): void;
    markForCheck(): void;
    /**
     * Data binds the hierarchical grid. No child grids will be created or rendered by default, unless there is initialExpandDepth >= 0 set.
     */
    dataBind(): void;
    /**
     * Returns the element of the root grid (igGrid)
     */
    root(): object;
    /**
     * Returns the widget object of the root grid (igGrid)
     */
    rootWidget(): object;
    /**
     * Returns a flat list of all child grid elements (recursive)
     */
    allChildren(): object;
    /**
     * Expands or collapses (toggles) a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback     Specifies a custom function to be called when parent row is toggled(optional).
     * Takes 2 arguments - first is hierarchical grid object, second is the row element that was toggled
     */
    toggle(element: Element, callback?: () => void): void;
    /**
     * Expands (toggles) a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param id     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback     Specifies a custom function to be called when parent row is expanded(optional).
     * Takes 2 arguments first is hierarchical grid object, second is the row element that was expanded
     */
    expand(id: Element, callback?: () => void): void;
    /**
     * Collapses a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param id accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback Specifies a custom function to be called when parent row is expanded(optional).
     * Takes 2 arguments - first is hierarchical grid object, second is the row element that was collapsed
     */
    collapse(id: Element, callback?: () => void): void;
    /**
     * Checks if a parent row is currently collapsed
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     */
    collapsed(element: Element): boolean;
    /**
     * Checks if a parent row is populated with data
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     */
    populated(element: Element): boolean;
    /**
     * Commits pending transactions to the client data source for main and all child grids.
     */
    commit(): void;
    /**
     * Clears the transaction log (delegates to igDataSource). Note that this does not update the UI.
     * In case the UI must be updated, set the second parameter "updateUI" to true, which will trigger a call to dataBind()
     * to re-render the contents.
     *
     * @param rebind     Whether to perform a rebind.
     */
    rollback(rebind?: boolean): void;
    /**
     * Posts to the settings.updateUrl using $.ajax, by serializing the changes as url params
     *
     * @param success    Specifies a custom function to be called when AJAX request to the updateUrl option succeeds(optional)
     * @param error    Specifies a custom function to be called when AJAX request to the updateUrl option fails(optional)
     */
    saveChanges(success: () => void, error: () => void): void;
    /**
     * Destroys the hierarchical grid by recursively destroying all child grids
     */
    destroy(): void;
}
