/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
export declare class IgPivotGridComponent extends IgControlBase<IgPivotGrid> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    set dataSource(value: any);
    private _dataSource;
    option(): void;
    ngOnInit(): void;
    /**
     * Returns the igGrid instance used to render the OLAP data.
     */
    grid(): object;
    /**
     * Triggers an update on the data source and the igPivotGrid.
     */
    updateGrid(): void;
    /**
     * Expands a member from the data source and returns true if the expand succeeds.
     * If the data source has a pending update, the method will return false.
     * Note that igPivotGrid to will display the expanded result after the data source is updated.
     *
     * @param tupleLocation The name of the parent axis - 'columnAxis' or 'rowAxis'.
     * @param tupleIndex The index of the containing tuple.
     * This index should correspond to the position of the tuple in the original unsorted result of the data source.
     * @param memberIndex The index of the member in the tuple.
     * This index should correspond to the position of the member in the original unsorted result of the data source.
     * @param shouldUpdate A flag indicating whether the data source should be updated after the expand.
     */
    expandTupleMember(tupleLocation: string, tupleIndex: number, memberIndex: number, shouldUpdate?: boolean): boolean;
    /**
     * Collapses a member from the data source and returns true if the collapse succeeds.
     * If the data source has a pending update, the method will return false.
     * Note that igPivotGrid to will display the expanded result after the data source is updated.
     *
     * @param tupleLocation The name of the parent axis - 'columnAxis' or 'rowAxis'.
     * @param tupleIndex The index of the containing tuple.
     * This index should correspond to the position of the tuple in the original unsorted result of the data source.
     * @param memberIndex The index of the member in the tuple.
     * This index should correspond to the position of the member in the original unsorted result of the data source.
     * @param shouldUpdate A flag indicating whether the data source should be updated after the expand.
     */
    collapseTupleMember(tupleLocation: string, tupleIndex: number, memberIndex: number, shouldUpdate?: boolean): boolean;
    /**
     * Returns an array with the applied sort directions on the igPivotGrid's columns.
     * The returned array contains objects with the following properties:
     *             memberNames: The names of the members in the tuple.
     *             tupleIndex: The index of the tuple on the column axis in the original unsorted result.
     *             sortDirection: The direction of the sort - ascending or descending.
     */
    appliedColumnSortDirections(): any[];
    /**
     * Returns an array with the applied level sort direction items, which were used for the sorting of the header cells.
     * The returned array contains objects with the following properties:
     *             levelUniqueName: Specifies the unique name of the level, which was sorted.
     *             sortDirection: The direction of the header sort - ascending or descending.
     */
    appliedLevelSortDirections(): any[];
    /**
     * Destroy is part of the jQuery UI widget API and does the following:
     *             1. Remove custom CSS classes that were added.
     *             2. Unwrap any wrapping elements such as scrolling divs and other containers.
     *             3. Unbind all events that were bound.
     */
    destroy(): void;
}
