/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
export declare class IgRatingComponent extends IgControlBase<IgRating> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Gets reference to [igValidator](ui.igvalidator) used by igRating.
     *
     * @param destroy     Request to destroy validator.
     */
    validator(destroy?: boolean): object;
    /**
     * Triggers validation.
     */
    validate(): boolean;
    /**
     * Gets/Sets (selected) value.
     *
     * @param val     New value which is rendered with selected css.
     * @return number|object     If parameter is not 'number', then exact value rendered with selected css is returned.
     * Otherwise, reference to igRating is returned.
     */
    value(val: number): number | object;
    /**
     * Gets/Sets hover value.
     *
     * @param val     New value which will be rendered with hover css when rating gets mouse.
     * @return number|object     If parameter is not "number", then last value which was rendered with hover css is returned.
     * Otherwise, reference to igRating is returned.
     */
    valueHover(val?: number): number | object;
    /**
     * Checks if igRating has focus.
     */
    hasFocus(): boolean;
    /**
     * Sets focus to igRating. That has effect only when options.focusable is enabled.
     */
    focus(): object;
    /**
     * Destroys igRating widget.
     */
    destroy(): object;
}
