/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgContentControlBase } from '../igcontrolbase/igcontentcontrolbase';
export declare class IgTileManagerComponent extends IgContentControlBase<IgTileManager> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    set dataSource(value: any);
    private _dataSource;
    ngOnInit(): void;
    /**
     * Maximizes a given tile.
     *
     * @param $tileToMaximize Specifies the jQuery object of the tile element to be maximized.
     * @param animDuration Specifies the animation duration for this maximizing.
     * @param event Indicates the browser even which triggered this action (not API).
     */
    maximize($tileToMaximize: object, animDuration?: number, event?: object): void;
    /**
     * Minimizes the maximized tile. Has no effect if no maximized tile is present.
     *
     * @param animDuration Specifies the animation duration for this minimize.
     * @param event Indicates the browser even which triggered this action (not API).
     */
    minimize(animDuration?: number, event?: object): void;
    /**
     * Returns the maximized tile or null if such is not present.
     * @return object|null Returns the maximized tile or null if such is not present.
     */
    maximizedTile(): object;
    /**
     * Returns an array with the tiles in minimized state or null if such are not present.
     * @return object|null Returns an array with the tiles in minimized state or null if such are not present.
     */
    minimizedTiles(): object;
    /**
     * Returns the splitter associated with this tile manager or
     *                 null if the tile manager was instantiated with maximizedTileIndex.
     * @return object|null Returns the splitter associated with this tile manager or null
     * if the tile manager was instantiated with maximizedTileIndex.
     */
    splitter(): object;
    /**
     * Returns the [layout manager](ui.iglayoutmanager) associated with current tile manager.
     */
    layoutManager(): object;
    /**
     * Reflow the tile manager. Rearranging the tiles to fit in the container
     *
     * @param forceReflow Indicates whether the reflow should be forced.
     * Useful in cases where the items size and position was changed manually.
     * @param animationDuration The animation duration to be used for this reflow only.
     * @param event Indicates the browser even which triggered this action (not API).
     */
    reflow(forceReflow?: object, animationDuration?: number, event?: object): void;
    /**
     * Returns the element that represents this widget.
     */
    widget(): object;
    /**
     * Causes the TileManager to data bind to the data source (local or remote) , and re-render all of the data as well.
     */
    dataBind(): void;
    /**
     * Deletes the widget instance (client object). It is no longer accessible and all its event handlers stop working.
     * Destroys all child widgets. Removes auto-generated HTML content, which is outside the widget, e.g. detached popups, dropdowns, etc.
     */
    destroy(): object;
}
