/// <reference types="ignite-ui" />
import { IterableDiffers, ElementRef, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
export declare class IgValidatorComponent extends IgControlBase<IgValidator> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    /**
     * Trigger validation and show errors for invalid fields.
     *
     * @param field    Optional field object, its selector or zero-based index to check.
     *  Only has effect with fields collection and skips other fields.
     */
    validate(field?: object): boolean;
    /**
     * Trigger validation but do not display error messages.
     *
     * @param field    Optional field object, its selector or zero-based index to check.
     * Only has effect with fields collection and skips other fields.
     */
    isValid(field?: object): boolean;
    /**
     * Hide any possible message(s) (either messageTarget or igNotifier).
     * 			Note: When the validator has a fields colleciton, not passing a field will hide messages on all fields.
     *
     * @param field    Optional field object, its selector or zero-based index to hide message for.
     */
    hide(field?: object): void;
    /**
     * Gets all current error messages for invalid field(s).
     * Note that this method does not valdiate and states and messages are only updated on validation, so
     * this can be used on formValidated event or after validate/isValid method calls.
     *
     * @param field    Optional field object, selector or zero-based index for a single field to get error message for.
     */
    getErrorMessages(field?: object): any[];
    /**
     * Check for currently displayed message(s). Takes an optional field.
     * 			Note: When the validator has a fields colleciton, not passing a
     *      field will return a cumulative true even if just one field has a visible message.
     *
     * @param field    Optional field object, selector or zero-based index for a single field to get error message for.
     */
    isMessageDisplayed(field?: object): boolean;
    /**
     * Gets the notifier for the igValidator or for a single filed.
     *
     * @param field    Optional field object, its selector or zero-based index to get notifier for.
     */
    notifier(field?: object): object;
    /**
     * Adds an new input to the fields collection and initializes it with the validator.
     * Note: Additional fields are only accepted if the validator has been created with the collection.
     *
     * @param field    An object with the field selector and options.
     */
    addField(field: object): void;
    /**
     * Removes an input from the fields collection.
     *
     * @param field    The field object to remove, its zero-based index or selector.
     */
    removeField(field: object): void;
    /**
     * Updates a field in the validator collection.
     * Used to reinitialize field in case a control has been created after the validator or to pass in new options.
     *
     * @param field    The field object to update, its zero-based index or selector.
     * @param fieldOptions    New options to apply to the field.
     */
    updateField(field: object, fieldOptions?: object): void;
    /**
     * Destroys the validator widget.
     */
    destroy(): void;
}
